/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataUpcloudHostsConfig extends cdktf.TerraformMetaArguments {
    /**
    * hosts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/data-sources/hosts#hosts DataUpcloudHosts#hosts}
    */
    readonly hosts?: DataUpcloudHostsHosts[] | cdktf.IResolvable;
}
export interface DataUpcloudHostsHostsStatistics {
}
export declare function dataUpcloudHostsHostsStatisticsToTerraform(struct?: DataUpcloudHostsHostsStatistics | cdktf.IResolvable): any;
export declare function dataUpcloudHostsHostsStatisticsToHclTerraform(struct?: DataUpcloudHostsHostsStatistics | cdktf.IResolvable): any;
export declare class DataUpcloudHostsHostsStatisticsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataUpcloudHostsHostsStatistics | cdktf.IResolvable | undefined;
    set internalValue(value: DataUpcloudHostsHostsStatistics | cdktf.IResolvable | undefined);
    get name(): string;
    get timestamp(): string;
    get value(): number;
}
export declare class DataUpcloudHostsHostsStatisticsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataUpcloudHostsHostsStatistics[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataUpcloudHostsHostsStatisticsOutputReference;
}
export interface DataUpcloudHostsHosts {
    /**
    * statistics block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/data-sources/hosts#statistics DataUpcloudHosts#statistics}
    */
    readonly statistics?: DataUpcloudHostsHostsStatistics[] | cdktf.IResolvable;
}
export declare function dataUpcloudHostsHostsToTerraform(struct?: DataUpcloudHostsHosts | cdktf.IResolvable): any;
export declare function dataUpcloudHostsHostsToHclTerraform(struct?: DataUpcloudHostsHosts | cdktf.IResolvable): any;
export declare class DataUpcloudHostsHostsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataUpcloudHostsHosts | cdktf.IResolvable | undefined;
    set internalValue(value: DataUpcloudHostsHosts | cdktf.IResolvable | undefined);
    get description(): string;
    get hostId(): number;
    get windowsEnabled(): cdktf.IResolvable;
    get zone(): string;
    private _statistics;
    get statistics(): DataUpcloudHostsHostsStatisticsList;
    putStatistics(value: DataUpcloudHostsHostsStatistics[] | cdktf.IResolvable): void;
    resetStatistics(): void;
    get statisticsInput(): cdktf.IResolvable | DataUpcloudHostsHostsStatistics[] | undefined;
}
export declare class DataUpcloudHostsHostsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataUpcloudHostsHosts[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataUpcloudHostsHostsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/data-sources/hosts upcloud_hosts}
*/
export declare class DataUpcloudHosts extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "upcloud_hosts";
    /**
    * Generates CDKTF code for importing a DataUpcloudHosts resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataUpcloudHosts to import
    * @param importFromId The id of the existing DataUpcloudHosts that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/data-sources/hosts#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataUpcloudHosts to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/data-sources/hosts upcloud_hosts} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataUpcloudHostsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataUpcloudHostsConfig);
    get id(): string;
    private _hosts;
    get hosts(): DataUpcloudHostsHostsList;
    putHosts(value: DataUpcloudHostsHosts[] | cdktf.IResolvable): void;
    resetHosts(): void;
    get hostsInput(): cdktf.IResolvable | DataUpcloudHostsHosts[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
