/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ManagedDatabaseValkeyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#id ManagedDatabaseValkey#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User defined key-value pairs to classify the managed database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#labels ManagedDatabaseValkey#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Maintenance window day of week. Lower case weekday name (monday, tuesday, ...)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#maintenance_window_dow ManagedDatabaseValkey#maintenance_window_dow}
    */
    readonly maintenanceWindowDow?: string;
    /**
    * Maintenance window UTC time in hh:mm:ss format
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#maintenance_window_time ManagedDatabaseValkey#maintenance_window_time}
    */
    readonly maintenanceWindowTime?: string;
    /**
    * Name of the service. The name is used as a prefix for the logical hostname. Must be unique within an account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#name ManagedDatabaseValkey#name}
    */
    readonly name: string;
    /**
    * Service plan to use. This determines how much resources the instance will have. You can list available plans with `upctl database plans <type>`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#plan ManagedDatabaseValkey#plan}
    */
    readonly plan: string;
    /**
    * The administrative power state of the service
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#powered ManagedDatabaseValkey#powered}
    */
    readonly powered?: boolean | cdktf.IResolvable;
    /**
    * If set to true, prevents the managed service from being powered off, or deleted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#termination_protection ManagedDatabaseValkey#termination_protection}
    */
    readonly terminationProtection?: boolean | cdktf.IResolvable;
    /**
    * Title of a managed database instance
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#title ManagedDatabaseValkey#title}
    */
    readonly title: string;
    /**
    * Zone where the instance resides, e.g. `de-fra1`. You can list available zones with `upctl zone list`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#zone ManagedDatabaseValkey#zone}
    */
    readonly zone: string;
    /**
    * network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#network ManagedDatabaseValkey#network}
    */
    readonly network?: ManagedDatabaseValkeyNetwork[] | cdktf.IResolvable;
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#properties ManagedDatabaseValkey#properties}
    */
    readonly properties?: ManagedDatabaseValkeyProperties;
}
export interface ManagedDatabaseValkeyComponents {
}
export declare function managedDatabaseValkeyComponentsToTerraform(struct?: ManagedDatabaseValkeyComponents): any;
export declare function managedDatabaseValkeyComponentsToHclTerraform(struct?: ManagedDatabaseValkeyComponents): any;
export declare class ManagedDatabaseValkeyComponentsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ManagedDatabaseValkeyComponents | undefined;
    set internalValue(value: ManagedDatabaseValkeyComponents | undefined);
    get component(): string;
    get host(): string;
    get port(): number;
    get route(): string;
    get usage(): string;
}
export declare class ManagedDatabaseValkeyComponentsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ManagedDatabaseValkeyComponentsOutputReference;
}
export interface ManagedDatabaseValkeyNodeStates {
}
export declare function managedDatabaseValkeyNodeStatesToTerraform(struct?: ManagedDatabaseValkeyNodeStates): any;
export declare function managedDatabaseValkeyNodeStatesToHclTerraform(struct?: ManagedDatabaseValkeyNodeStates): any;
export declare class ManagedDatabaseValkeyNodeStatesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ManagedDatabaseValkeyNodeStates | undefined;
    set internalValue(value: ManagedDatabaseValkeyNodeStates | undefined);
    get name(): string;
    get role(): string;
    get state(): string;
}
export declare class ManagedDatabaseValkeyNodeStatesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ManagedDatabaseValkeyNodeStatesOutputReference;
}
export interface ManagedDatabaseValkeyNetwork {
    /**
    * Network family. Currently only `IPv4` is supported.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#family ManagedDatabaseValkey#family}
    */
    readonly family: string;
    /**
    * The name of the network. Must be unique within the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#name ManagedDatabaseValkey#name}
    */
    readonly name: string;
    /**
    * The type of the network. Must be private.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#type ManagedDatabaseValkey#type}
    */
    readonly type: string;
    /**
    * Private network UUID. Must reside in the same zone as the database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#uuid ManagedDatabaseValkey#uuid}
    */
    readonly uuid: string;
}
export declare function managedDatabaseValkeyNetworkToTerraform(struct?: ManagedDatabaseValkeyNetwork | cdktf.IResolvable): any;
export declare function managedDatabaseValkeyNetworkToHclTerraform(struct?: ManagedDatabaseValkeyNetwork | cdktf.IResolvable): any;
export declare class ManagedDatabaseValkeyNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ManagedDatabaseValkeyNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: ManagedDatabaseValkeyNetwork | cdktf.IResolvable | undefined);
    private _family?;
    get family(): string;
    set family(value: string);
    get familyInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _uuid?;
    get uuid(): string;
    set uuid(value: string);
    get uuidInput(): string | undefined;
}
export declare class ManagedDatabaseValkeyNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ManagedDatabaseValkeyNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ManagedDatabaseValkeyNetworkOutputReference;
}
export interface ManagedDatabaseValkeyPropertiesMigration {
    /**
    * Database name for bootstrapping the initial connection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#dbname ManagedDatabaseValkey#dbname}
    */
    readonly dbname?: string;
    /**
    * Hostname or IP address of the server where to migrate data from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#host ManagedDatabaseValkey#host}
    */
    readonly host?: string;
    /**
    * Comma-separated list of databases, which should be ignored during migration (supported by MySQL and PostgreSQL only at the moment).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#ignore_dbs ManagedDatabaseValkey#ignore_dbs}
    */
    readonly ignoreDbs?: string;
    /**
    * Comma-separated list of database roles, which should be ignored during migration (supported by PostgreSQL only at the moment).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#ignore_roles ManagedDatabaseValkey#ignore_roles}
    */
    readonly ignoreRoles?: string;
    /**
    * The migration method to be used (currently supported only by Redis, Dragonfly, MySQL and PostgreSQL service types).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#method ManagedDatabaseValkey#method}
    */
    readonly method?: string;
    /**
    * Password for authentication with the server where to migrate data from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#password ManagedDatabaseValkey#password}
    */
    readonly password?: string;
    /**
    * Port number of the server where to migrate data from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#port ManagedDatabaseValkey#port}
    */
    readonly port?: number;
    /**
    * The server where to migrate data from is secured with SSL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#ssl ManagedDatabaseValkey#ssl}
    */
    readonly ssl?: boolean | cdktf.IResolvable;
    /**
    * User name for authentication with the server where to migrate data from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#username ManagedDatabaseValkey#username}
    */
    readonly username?: string;
}
export declare function managedDatabaseValkeyPropertiesMigrationToTerraform(struct?: ManagedDatabaseValkeyPropertiesMigrationOutputReference | ManagedDatabaseValkeyPropertiesMigration): any;
export declare function managedDatabaseValkeyPropertiesMigrationToHclTerraform(struct?: ManagedDatabaseValkeyPropertiesMigrationOutputReference | ManagedDatabaseValkeyPropertiesMigration): any;
export declare class ManagedDatabaseValkeyPropertiesMigrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ManagedDatabaseValkeyPropertiesMigration | undefined;
    set internalValue(value: ManagedDatabaseValkeyPropertiesMigration | undefined);
    private _dbname?;
    get dbname(): string;
    set dbname(value: string);
    resetDbname(): void;
    get dbnameInput(): string | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _ignoreDbs?;
    get ignoreDbs(): string;
    set ignoreDbs(value: string);
    resetIgnoreDbs(): void;
    get ignoreDbsInput(): string | undefined;
    private _ignoreRoles?;
    get ignoreRoles(): string;
    set ignoreRoles(value: string);
    resetIgnoreRoles(): void;
    get ignoreRolesInput(): string | undefined;
    private _method?;
    get method(): string;
    set method(value: string);
    resetMethod(): void;
    get methodInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _ssl?;
    get ssl(): boolean | cdktf.IResolvable;
    set ssl(value: boolean | cdktf.IResolvable);
    resetSsl(): void;
    get sslInput(): boolean | cdktf.IResolvable | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
}
export interface ManagedDatabaseValkeyProperties {
    /**
    * Automatic utility network IP Filter. Automatically allow connections from servers in the utility network within the same zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#automatic_utility_network_ip_filter ManagedDatabaseValkey#automatic_utility_network_ip_filter}
    */
    readonly automaticUtilityNetworkIpFilter?: boolean | cdktf.IResolvable;
    /**
    * The hour of day (in UTC) when backup for the service is started. New backup is only started if previous backup has already completed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#backup_hour ManagedDatabaseValkey#backup_hour}
    */
    readonly backupHour?: number;
    /**
    * The minute of an hour when backup for the service is started. New backup is only started if previous backup has already completed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#backup_minute ManagedDatabaseValkey#backup_minute}
    */
    readonly backupMinute?: number;
    /**
    * Frequent RDB snapshots. When enabled, Valkey will create frequent local RDB snapshots. When disabled, Valkey will only take RDB snapshots when a backup is created, based on the backup schedule. This setting is ignored when `valkey_persistence` is set to `off`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#frequent_snapshots ManagedDatabaseValkey#frequent_snapshots}
    */
    readonly frequentSnapshots?: boolean | cdktf.IResolvable;
    /**
    * IP filter. Allow incoming connections from CIDR address block, e.g. '10.20.0.0/16'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#ip_filter ManagedDatabaseValkey#ip_filter}
    */
    readonly ipFilter?: string[];
    /**
    * Public Access. Allow access to the service from the public Internet.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#public_access ManagedDatabaseValkey#public_access}
    */
    readonly publicAccess?: boolean | cdktf.IResolvable;
    /**
    * Service logging. Store logs for the service so that they are available in the HTTP API and console.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#service_log ManagedDatabaseValkey#service_log}
    */
    readonly serviceLog?: boolean | cdktf.IResolvable;
    /**
    * Default ACL for pub/sub channels used when a Valkey user is created. Determines default pub/sub channels' ACL for new users if ACL is not supplied. When this option is not defined, all_channels is assumed to keep backward compatibility. This option doesn't affect Valkey configuration acl-pubsub-default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_acl_channels_default ManagedDatabaseValkey#valkey_acl_channels_default}
    */
    readonly valkeyAclChannelsDefault?: string;
    /**
    * Active expire effort. Valkey reclaims expired keys both when accessed and in the background. The background process scans for expired keys to free memory. Increasing the active-expire-effort setting (default 1, max 10) uses more CPU to reclaim expired keys faster, reducing memory usage but potentially increasing latency.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_active_expire_effort ManagedDatabaseValkey#valkey_active_expire_effort}
    */
    readonly valkeyActiveExpireEffort?: number;
    /**
    * Valkey IO thread count. Set Valkey IO thread count. Changing this will cause a restart of the Valkey service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_io_threads ManagedDatabaseValkey#valkey_io_threads}
    */
    readonly valkeyIoThreads?: number;
    /**
    * LFU maxmemory-policy counter decay time in minutes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_lfu_decay_time ManagedDatabaseValkey#valkey_lfu_decay_time}
    */
    readonly valkeyLfuDecayTime?: number;
    /**
    * Counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory-policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_lfu_log_factor ManagedDatabaseValkey#valkey_lfu_log_factor}
    */
    readonly valkeyLfuLogFactor?: number;
    /**
    * Valkey maxmemory-policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_maxmemory_policy ManagedDatabaseValkey#valkey_maxmemory_policy}
    */
    readonly valkeyMaxmemoryPolicy?: string;
    /**
    * Set notify-keyspace-events option.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_notify_keyspace_events ManagedDatabaseValkey#valkey_notify_keyspace_events}
    */
    readonly valkeyNotifyKeyspaceEvents?: string;
    /**
    * Number of Valkey databases. Set number of Valkey databases. Changing this will cause a restart of the Valkey service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_number_of_databases ManagedDatabaseValkey#valkey_number_of_databases}
    */
    readonly valkeyNumberOfDatabases?: number;
    /**
    * Valkey persistence. When persistence is 'rdb', Valkey does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is 'off', no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_persistence ManagedDatabaseValkey#valkey_persistence}
    */
    readonly valkeyPersistence?: string;
    /**
    * Pub/sub client output buffer hard limit in MB. Set output buffer limit for pub / sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_pubsub_client_output_buffer_limit ManagedDatabaseValkey#valkey_pubsub_client_output_buffer_limit}
    */
    readonly valkeyPubsubClientOutputBufferLimit?: number;
    /**
    * Require SSL to access Valkey.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_ssl ManagedDatabaseValkey#valkey_ssl}
    */
    readonly valkeySsl?: boolean | cdktf.IResolvable;
    /**
    * Valkey idle connection timeout in seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#valkey_timeout ManagedDatabaseValkey#valkey_timeout}
    */
    readonly valkeyTimeout?: number;
    /**
    * migration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#migration ManagedDatabaseValkey#migration}
    */
    readonly migration?: ManagedDatabaseValkeyPropertiesMigration;
}
export declare function managedDatabaseValkeyPropertiesToTerraform(struct?: ManagedDatabaseValkeyPropertiesOutputReference | ManagedDatabaseValkeyProperties): any;
export declare function managedDatabaseValkeyPropertiesToHclTerraform(struct?: ManagedDatabaseValkeyPropertiesOutputReference | ManagedDatabaseValkeyProperties): any;
export declare class ManagedDatabaseValkeyPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ManagedDatabaseValkeyProperties | undefined;
    set internalValue(value: ManagedDatabaseValkeyProperties | undefined);
    private _automaticUtilityNetworkIpFilter?;
    get automaticUtilityNetworkIpFilter(): boolean | cdktf.IResolvable;
    set automaticUtilityNetworkIpFilter(value: boolean | cdktf.IResolvable);
    resetAutomaticUtilityNetworkIpFilter(): void;
    get automaticUtilityNetworkIpFilterInput(): boolean | cdktf.IResolvable | undefined;
    private _backupHour?;
    get backupHour(): number;
    set backupHour(value: number);
    resetBackupHour(): void;
    get backupHourInput(): number | undefined;
    private _backupMinute?;
    get backupMinute(): number;
    set backupMinute(value: number);
    resetBackupMinute(): void;
    get backupMinuteInput(): number | undefined;
    private _frequentSnapshots?;
    get frequentSnapshots(): boolean | cdktf.IResolvable;
    set frequentSnapshots(value: boolean | cdktf.IResolvable);
    resetFrequentSnapshots(): void;
    get frequentSnapshotsInput(): boolean | cdktf.IResolvable | undefined;
    private _ipFilter?;
    get ipFilter(): string[];
    set ipFilter(value: string[]);
    resetIpFilter(): void;
    get ipFilterInput(): string[] | undefined;
    private _publicAccess?;
    get publicAccess(): boolean | cdktf.IResolvable;
    set publicAccess(value: boolean | cdktf.IResolvable);
    resetPublicAccess(): void;
    get publicAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _serviceLog?;
    get serviceLog(): boolean | cdktf.IResolvable;
    set serviceLog(value: boolean | cdktf.IResolvable);
    resetServiceLog(): void;
    get serviceLogInput(): boolean | cdktf.IResolvable | undefined;
    private _valkeyAclChannelsDefault?;
    get valkeyAclChannelsDefault(): string;
    set valkeyAclChannelsDefault(value: string);
    resetValkeyAclChannelsDefault(): void;
    get valkeyAclChannelsDefaultInput(): string | undefined;
    private _valkeyActiveExpireEffort?;
    get valkeyActiveExpireEffort(): number;
    set valkeyActiveExpireEffort(value: number);
    resetValkeyActiveExpireEffort(): void;
    get valkeyActiveExpireEffortInput(): number | undefined;
    private _valkeyIoThreads?;
    get valkeyIoThreads(): number;
    set valkeyIoThreads(value: number);
    resetValkeyIoThreads(): void;
    get valkeyIoThreadsInput(): number | undefined;
    private _valkeyLfuDecayTime?;
    get valkeyLfuDecayTime(): number;
    set valkeyLfuDecayTime(value: number);
    resetValkeyLfuDecayTime(): void;
    get valkeyLfuDecayTimeInput(): number | undefined;
    private _valkeyLfuLogFactor?;
    get valkeyLfuLogFactor(): number;
    set valkeyLfuLogFactor(value: number);
    resetValkeyLfuLogFactor(): void;
    get valkeyLfuLogFactorInput(): number | undefined;
    private _valkeyMaxmemoryPolicy?;
    get valkeyMaxmemoryPolicy(): string;
    set valkeyMaxmemoryPolicy(value: string);
    resetValkeyMaxmemoryPolicy(): void;
    get valkeyMaxmemoryPolicyInput(): string | undefined;
    private _valkeyNotifyKeyspaceEvents?;
    get valkeyNotifyKeyspaceEvents(): string;
    set valkeyNotifyKeyspaceEvents(value: string);
    resetValkeyNotifyKeyspaceEvents(): void;
    get valkeyNotifyKeyspaceEventsInput(): string | undefined;
    private _valkeyNumberOfDatabases?;
    get valkeyNumberOfDatabases(): number;
    set valkeyNumberOfDatabases(value: number);
    resetValkeyNumberOfDatabases(): void;
    get valkeyNumberOfDatabasesInput(): number | undefined;
    private _valkeyPersistence?;
    get valkeyPersistence(): string;
    set valkeyPersistence(value: string);
    resetValkeyPersistence(): void;
    get valkeyPersistenceInput(): string | undefined;
    private _valkeyPubsubClientOutputBufferLimit?;
    get valkeyPubsubClientOutputBufferLimit(): number;
    set valkeyPubsubClientOutputBufferLimit(value: number);
    resetValkeyPubsubClientOutputBufferLimit(): void;
    get valkeyPubsubClientOutputBufferLimitInput(): number | undefined;
    private _valkeySsl?;
    get valkeySsl(): boolean | cdktf.IResolvable;
    set valkeySsl(value: boolean | cdktf.IResolvable);
    resetValkeySsl(): void;
    get valkeySslInput(): boolean | cdktf.IResolvable | undefined;
    private _valkeyTimeout?;
    get valkeyTimeout(): number;
    set valkeyTimeout(value: number);
    resetValkeyTimeout(): void;
    get valkeyTimeoutInput(): number | undefined;
    private _migration;
    get migration(): ManagedDatabaseValkeyPropertiesMigrationOutputReference;
    putMigration(value: ManagedDatabaseValkeyPropertiesMigration): void;
    resetMigration(): void;
    get migrationInput(): ManagedDatabaseValkeyPropertiesMigration | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey upcloud_managed_database_valkey}
*/
export declare class ManagedDatabaseValkey extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_managed_database_valkey";
    /**
    * Generates CDKTF code for importing a ManagedDatabaseValkey resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ManagedDatabaseValkey to import
    * @param importFromId The id of the existing ManagedDatabaseValkey that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ManagedDatabaseValkey to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_database_valkey upcloud_managed_database_valkey} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ManagedDatabaseValkeyConfig
    */
    constructor(scope: Construct, id: string, config: ManagedDatabaseValkeyConfig);
    private _components;
    get components(): ManagedDatabaseValkeyComponentsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _maintenanceWindowDow?;
    get maintenanceWindowDow(): string;
    set maintenanceWindowDow(value: string);
    resetMaintenanceWindowDow(): void;
    get maintenanceWindowDowInput(): string | undefined;
    private _maintenanceWindowTime?;
    get maintenanceWindowTime(): string;
    set maintenanceWindowTime(value: string);
    resetMaintenanceWindowTime(): void;
    get maintenanceWindowTimeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nodeStates;
    get nodeStates(): ManagedDatabaseValkeyNodeStatesList;
    private _plan?;
    get plan(): string;
    set plan(value: string);
    get planInput(): string | undefined;
    private _powered?;
    get powered(): boolean | cdktf.IResolvable;
    set powered(value: boolean | cdktf.IResolvable);
    resetPowered(): void;
    get poweredInput(): boolean | cdktf.IResolvable | undefined;
    get primaryDatabase(): string;
    get serviceHost(): string;
    get servicePassword(): string;
    get servicePort(): string;
    get serviceUri(): string;
    get serviceUsername(): string;
    get state(): string;
    private _terminationProtection?;
    get terminationProtection(): boolean | cdktf.IResolvable;
    set terminationProtection(value: boolean | cdktf.IResolvable);
    resetTerminationProtection(): void;
    get terminationProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    get titleInput(): string | undefined;
    get type(): string;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    get zoneInput(): string | undefined;
    private _network;
    get network(): ManagedDatabaseValkeyNetworkList;
    putNetwork(value: ManagedDatabaseValkeyNetwork[] | cdktf.IResolvable): void;
    resetNetwork(): void;
    get networkInput(): cdktf.IResolvable | ManagedDatabaseValkeyNetwork[] | undefined;
    private _properties;
    get properties(): ManagedDatabaseValkeyPropertiesOutputReference;
    putProperties(value: ManagedDatabaseValkeyProperties): void;
    resetProperties(): void;
    get propertiesInput(): ManagedDatabaseValkeyProperties | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
