/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ManagedObjectStorageBucketConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_object_storage_bucket#name ManagedObjectStorageBucket#name}
    */
    readonly name: string;
    /**
    * Managed Object Storage service UUID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_object_storage_bucket#service_uuid ManagedObjectStorageBucket#service_uuid}
    */
    readonly serviceUuid: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_object_storage_bucket upcloud_managed_object_storage_bucket}
*/
export declare class ManagedObjectStorageBucket extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_managed_object_storage_bucket";
    /**
    * Generates CDKTF code for importing a ManagedObjectStorageBucket resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ManagedObjectStorageBucket to import
    * @param importFromId The id of the existing ManagedObjectStorageBucket that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_object_storage_bucket#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ManagedObjectStorageBucket to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.20.0/docs/resources/managed_object_storage_bucket upcloud_managed_object_storage_bucket} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ManagedObjectStorageBucketConfig
    */
    constructor(scope: Construct, id: string, config: ManagedObjectStorageBucketConfig);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _serviceUuid?;
    get serviceUuid(): string;
    set serviceUuid(value: string);
    get serviceUuidInput(): string | undefined;
    get totalObjects(): number;
    get totalSizeBytes(): number;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
